.. _exceptions:

Exceptions
++++++++++

.. autoclass:: qts.QtsError
.. autoclass:: qts.InternalError
.. autoclass:: qts.InvalidWrapperError
.. autoclass:: qts.MultipleWrappersAvailableError
.. autoclass:: qts.NoWrapperAvailableError
.. autoclass:: qts.NoWrapperSelectedError
.. autoclass:: qts.WrapperAlreadySelectedError
